@@ -1,6 +1,6 @@
 package Dancer2::Plugin::Auth::Extensible;
 
-our $VERSION = '0.600';
+our $VERSION = '0.601';
 
 use strict;
 use warnings;
@@ -18,43 +18,37 @@ use Dancer2::Plugin;
 has denied_page => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '/login/denied' },
+    from_config => sub { '/login/denied' },
 );
 
 has disable_roles => (
     is          => 'ro',
     isa         => Bool,
-    from_config => 1,
-    default     => sub { 0 },
+    from_config => sub { 0 },
 );
 
 has exit_page => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '/' },
+    from_config => sub { '/' },
 );
 
 has login_page => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '/login' },
+    from_config => sub { '/login' },
 );
 
 has login_page_handler => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '_default_login_page' },
+    from_config => sub { '_default_login_page' },
 );
 
 has logout_page => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '/logout' },
+    from_config => sub { '/logout' },
 );
 
 has no_login_handler => (
@@ -67,100 +61,86 @@ has no_login_handler => (
 has mailer => (
     is          => 'ro',
     isa         => HashRef,
-    from_config => 1,
-    default     => sub { '' },
+    from_config => sub { '' },
 );
 
 has mail_from => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '' },
+    from_config => sub { '' },
 );
 
 has no_default_pages => (
     is          => 'ro',
     isa         => Bool,
-    from_config => 1,
-    default     => sub { 0 },
+    from_config => sub { 0 },
 );
 
 has password_generator => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '_default_password_generator' },
+    from_config => sub { '_default_password_generator' },
 );
 
 has password_reset_send_email => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '_default_email_password_reset' },
+    from_config => sub { '_default_email_password_reset' },
 );
 
 has password_reset_text => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '' },
+    from_config => sub { '' },
 );
 
 has permission_denied_handler => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '_default_permission_denied_handler' },
+    from_config => sub { '_default_permission_denied_handler' },
 );
 
 has permission_denied_page_handler => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '_default_permission_denied_page' },
+    from_config => sub { '_default_permission_denied_page' },
 );
 
 has realms => (
     is          => 'ro',
     isa         => HashRef,
-    from_config => 1,
-    default     => sub { {} },
+    from_config => sub { {} },
 );
 
 has record_lastlogin => (
     is          => 'ro',
     isa         => Bool,
-    from_config => 1,
-    default     => sub { 0 },
+    from_config => sub { 0 },
 );
 
 has reset_password_handler => (
     is          => 'ro',
     isa         => Bool,
-    from_config => 1,
-    default     => sub { 0 },
+    from_config => sub { 0 },
     plugin_keyword => 1,
 );
 
 has user_home_page => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '/' },
+    from_config => sub { '/' },
 );
 
 has welcome_send => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '_default_welcome_send' },
+    from_config => sub { '_default_welcome_send' },
 );
 
 has welcome_text => (
     is          => 'ro',
     isa         => Str,
-    from_config => 1,
-    default     => sub { '' },
+    from_config => sub { '' },
 );
 
 #
@@ -224,7 +204,6 @@ sub BUILD {
             regexp => qr!^$login_page/?([\w]{32})?$!,
             code   => sub {
                 my $app = shift;
-                my $plugin = $app->with_plugin('Auth::Extensible');
 
                 if ( $plugin->logged_in_user ) {
                     $app->redirect( $app->request->params->{return_url}
@@ -253,7 +232,6 @@ sub BUILD {
             regexp => qr!^$denied_page$!,
             code   => sub {
                 my $app = shift;
-                my $plugin = $app->with_plugin('Auth::Extensible');
                 $app->response->status(403);
                 no strict 'refs';
                 return &{ $plugin->permission_denied_page_handler }($plugin);
@@ -300,10 +278,10 @@ sub auth_provider {
     # OK, we need to find out what provider this realm uses, and get an instance
     # of that provider, configured with the settings from the realm.
     my $realm_settings = $plugin->realms->{$realm}
-      or die "Invalid realm $realm";
+      or croak "Invalid realm $realm";
 
     my $provider_class = $realm_settings->{provider}
-      or die "No provider configured - consult documentation for "
+      or croak "No provider configured - consult documentation for "
       . __PACKAGE__;
 
     if ( $provider_class !~ /::/ ) {
@@ -350,7 +328,7 @@ sub create_user {
     my %options = @_;
 
     my @all_realms = keys %{ $plugin->realms };
-    die "Realm must be specified when more than one realm configured"
+    croak "Realm must be specified when more than one realm configured"
       if !$options{realm} && @all_realms > 1;
 
     my $realm = delete $options{realm} || $all_realms[0];
@@ -438,7 +416,7 @@ sub password_reset_send {
       : ( keys %{ $plugin->realms } );
 
     my $username = $options{username}
-      or die "username must be passed to password_reset_send";
+      or croak "username must be passed to password_reset_send";
 
     foreach my $realm (@realms_to_check) {
         my $this_result;
@@ -532,7 +510,7 @@ sub update_user {
     my $session = $plugin->app->session;
 
     my @all_realms = keys %{ $plugin->realms };
-    die "Realm must be specified when more than one realm configured"
+    croak "Realm must be specified when more than one realm configured"
       if !$update{realm} && @all_realms > 1;
 
     my $realm    = delete $update{realm} || $all_realms[0];
@@ -586,7 +564,7 @@ sub user_password {
             my $provider = $plugin->auth_provider($realm_check);
 
             # Realm may not support get_user_by_code
-            my $username = try {
+            $username = try {
                 $provider->get_user_by_code($code);
             }
             catch {
@@ -607,7 +585,7 @@ sub user_password {
     else {
         if ( !$params{username} ) {
             $username = $plugin->app->session->read('logged_in_user')
-              or die "No username specified and no logged-in user";
+              or croak "No username specified and no logged-in user";
             $realm = $plugin->app->session->read('logged_in_user_realm');
         }
         else {
@@ -897,7 +875,7 @@ sub _email_mail_message {
         data        => $params{html},
       ) if ( $params{html} );
 
-    @parts or die "No plain or HTML email text supplied";
+    @parts or croak "No plain or HTML email text supplied";
 
     my $content_type = @parts > 1 ? 'multipart/alternative' : $parts[0]->type;
 
@@ -913,10 +891,10 @@ sub _email_mail_message {
 sub _send_email {
     my $plugin = shift;
 
-    my $mailer = $plugin->mailer or die "No mailer configured";
+    my $mailer = $plugin->mailer or croak "No mailer configured";
 
     my $module = $mailer->{module}
-      or die "No email module specified for mailer";
+      or croak "No email module specified for mailer";
 
     if ( $module eq 'Mail::Message' ) {
 
@@ -925,7 +903,7 @@ sub _send_email {
         return $plugin->_email_mail_message(@_);
     }
     else {
-        die "No support for $module. Please submit a PR!";
+        croak "No support for $module. Please submit a PR!";
     }
 }
 
@@ -942,7 +920,7 @@ sub _try_realms {
     for my $realm ( keys %{ $plugin->realms } ) {
         my $provider = $plugin->auth_provider($realm);
         if ( !$provider->can($method) ) {
-            die "Provider $provider does not provide a $method method!";
+            croak "Provider $provider does not provide a $method method!";
         }
         if ( defined( my $result = $provider->$method(@args) ) ) {
             return $result;
@@ -986,8 +964,8 @@ sub _post_login_route {
         && $app->request->param('submit_reset') )
     {
         my $username = $app->request->param('username_reset');
-        die "Attempt to pass reference to reset blocked" if ref $username;
-        $app->password_reset_send( username => $username );
+        croak "Attempt to pass reference to reset blocked" if ref $username;
+        $plugin->password_reset_send( username => $username );
         $app->forward(
             $plugin->login_page,
             { reset_sent => 1 },
@@ -1030,7 +1008,7 @@ sub _post_login_route {
         if ( ref $_ ) {
 
             # TODO: handle more cleanly
-            die "Attempt to pass a reference as username/password blocked";
+            croak "Attempt to pass a reference as username/password blocked";
         }
     }
 
